abacusai.custom_chat_instructions — AbacusAI documentation

# abacusai.custom_chat_instructions

## Classes

`CustomChatInstructions` | Custom Chat Instructions

## Module Contents

class abacusai.custom_chat_instructions.CustomChatInstructions(client, userInformationInstructions=None, responseInstructions=None, enableCodeExecution=None, enableImageGeneration=None, enableWebSearch=None, enablePlayground=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Custom Chat Instructions

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - userInformationInstructions (str) – The behavior instructions for the chat.

    - responseInstructions (str) – The response instructions for the chat.

    - enableCodeExecution (bool) – Whether or not code execution is enabled.

    - enableImageGeneration (bool) – Whether or not image generation is enabled.

    - enableWebSearch (bool) – Whether or not web search is enabled.

    - enablePlayground (bool) – Whether or not playground is enabled.

  user_information_instructions = None
  response_instructions = None
  enable_code_execution = None
  enable_image_generation = None
  enable_web_search = None
  enable_playground = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict